Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3518)

Unified Diff: chrome/installer/gcapi_mac/gcapi.mm

Issue 2145723002: gcapi_mac: Support installation on macOS 10.12 (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/gcapi_mac/gcapi.mm
diff --git a/chrome/installer/gcapi_mac/gcapi.mm b/chrome/installer/gcapi_mac/gcapi.mm
index c95c2ab660af00039f6d32b5955a9a208f1b9eb4..798a53966f83776cdd58dd17497e1f12c7695a3d 100644
--- a/chrome/installer/gcapi_mac/gcapi.mm
+++ b/chrome/installer/gcapi_mac/gcapi.mm
@@ -58,8 +58,8 @@ bool IsOSXVersionSupported() {
// 10.2.
int mac_os_x_minor_version = darwin_major_version - 4;
- // Chrome is known to work on 10.9 - 10.11.
- return mac_os_x_minor_version >= 9 && mac_os_x_minor_version <= 11;
+ // Chrome is known to work on 10.9 - 10.12.
+ return mac_os_x_minor_version >= 9 && mac_os_x_minor_version <= 12;
}
// Returns the pid/gid of the logged-in user, even if getuid() claims that the
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698